[−][src]Module bastion_executor::load_balancer
Module for gathering statistics about the run queues of the runtime
Load balancer calculates sampled mean to provide average process execution amount to all runtime.
Structs
| LoadBalancer | Load-balancer struct which is just a convenience wrapper over the statistics calculations. |
| Stats | Holding all statistics related to the run queue |
Functions
| core_retrieval | Retrieve core count for the runtime scheduling purposes |
| stats | Static access to runtime statistics |