Sleepers

Struct Sleepers 

pub struct Sleepers { /* private fields */ }
The place where worker threads go to sleep.

Similar to how thread parking works, if a notification comes up while no threads are sleeping, the next thread that attempts to go to sleep will pick up the notification immediately.

Implementations

Source

impl Sleepers

pub fn new() -> Self

Creates a new Sleepers.

pub fn wait(&self)

Puts the current thread to sleep.

pub fn notify_one(&self)

Notifies one thread.