pub struct Sleepers { /* private fields */ }Expand description
The place where worker threads go to sleep.
Similar to how thread parking works, if a notification comes up while no threads are sleeping, the next thread that attempts to go to sleep will pick up the notification immediately.
Implementations